==> crud-el-0.2.29.tgz: package/src/CrudEl/Component/DefConfig.ts <==
/** 系统默认配置参数 */
export const DefParams: SystemParametersType = {
    /** DeBug 开关 */
    debug: false,

    /** 可操作最大高度 */
    mainMaxHeight: 700,
    /** 开启在Mount后自动查询 */
    isAfterMountQuery: false,
    /** 开启搜索表单 */
    isOpenSearchForm: false,
    /** 表单标签宽度 */
    Form_LabelWidth: 120,
    /** 对话框宽度 */
    Dialog_Width: 800,
    /** 开启全屏 */
    Dialog_isFullscreen: false,
    /** 启ESC关闭对话框 */
    Dialog_isCloseOnPressEscape: true,
    /** 开启点击modal关闭对话框 */
    Dialog_isCloseOnClickModal: false,
    /** 开启页脚按钮 */
    Dialog_isFooterButton: true,

    /** 开启索引 */
    Table_isOpenIndex: false,
    /** 开启多选 */
    Table_isOpenMultipleSelection: false,
    /** 开启展开行 */
    Table_isOpenExpand: true,
    /** 展开行数量 */
    Table_ExpandColumn: 4,
    /** 是否显示菜单栏 */
    Table_IsShowMenu: true,
    /** 操作菜单宽度 */
    Table_MenuWidth: 200,
    /** 操作菜单对齐 */
    Table_MenuAlign: 'left',
    /** 分页大小 */
    Page_PageSizes: [10, 20, 50, 100],
    /** 分页查询参数 */
    Page_PageParams: {
        current: 1,
        pageSize: 10,
        total: 0
    },
    /** 分页布局 */
    Page_Layout: '->,total, sizes, prev, pager, next, jumper',
    /** 只有一页时隐藏分页 */
    Page_isHideOnSinglePage: false,

    /** 查询时api接口name名称 */
    ApiName: {
        query: 'query',
        add: 'add',
        edit: 'edit',
        delete: 'delete',
        deleteFlag: 'deleteFlag',
        remove: 'remove'
    },
    /** 渲染时页面节点权限参数 */
    Permission: {
        add: 'add',
        edit: 'edit',
        delete: 'delete',
        deleteFlag: 'deleteFlag',
        remove: 'remove'
    },
    /** 所拥有的权限列表 */
    Permissions: ['add', 'edit', 'delete', 'deleteFlag', 'remove']
}

/** 组件共享参数 */
export const DefCrudState: CrusStateType = {
    CompRef: {},
    /** 当前操作是新增还是编辑 */
    Mode: 'add',
    /**新增/编辑对话框可见 */
    DialogVisible: false,
    /**表格加载状态 */
    tableLoading: false,
    /**表单提交加载状态 */
    submitLoading: false,
    /** 编辑表单 页脚显示状态 */
    DialogVisibleFooterButton: true,

    /** 拆分元素 */
    ElementArrs: { filter: {}, editor: {}, column: {}, columns: {} },
    // TODO:表格列动态展示未启动
    /** 要展示的表格列 */
    tableColumn: [],
    /**存储原始数据 */
    originalData: [],
    /**请求的数据 */
    tableData: [],
    /**选中的数据 */
    multipleSelection: [],
    /**上传的文件暂存 */
    uploadFiles: [],

    /**初始化的值 */
    initSearchModel: {},
    initEditModel: {},

    /**路由传参的值 */
    searchFormValue: {},
    /**搜索表单数据 */
    searchModel: {},
    /** 原始编辑值 */
    editFormValue: {},
    /**编辑表单数据 */
    editModel: {}
}

/** 根组件传入的Props */
export let DefCrudProps: CrudPropsType

==> crud-el-0.2.31.tgz: package/src/CrudEl/Component/DefConfig.ts <==
/** 系统默认配置参数 */
export const DefParams: SystemParametersType = {
    /** DeBug 开关 */
    debug: false,

    /** 开启在Mount后自动查询 */
    isAfterMountQuery: false,
    /** 开启搜索表单 */
    isOpenSearchForm: false,
    /** 表单标签宽度 */
    Form_LabelWidth: 120,
    /** 对话框宽度 */
    Dialog_Width: 800,
    /** 开启全屏 */
    Dialog_isFullscreen: false,
    /** 启ESC关闭对话框 */
    Dialog_isCloseOnPressEscape: true,
    /** 开启点击modal关闭对话框 */
    Dialog_isCloseOnClickModal: false,
    /** 开启页脚按钮 */
    Dialog_isFooterButton: true,

    /** 开启索引 */
    Table_isOpenIndex: false,
    /** 开启多选 */
    Table_isOpenMultipleSelection: false,
    /** 开启展开行 */
    Table_isOpenExpand: true,
    /** 展开行数量 */
    Table_ExpandColumn: 4,
    /** 是否显示菜单栏 */
    Table_IsShowMenu: true,
    /** 操作菜单宽度 */
    Table_MenuWidth: 200,
    /** 操作菜单对齐 */
    Table_MenuAlign: 'left',
    /** 分页大小 */
    Page_PageSizes: [10, 20, 50, 100],
    /** 分页查询参数 */
    Page_PageParams: {
        current: 1,
        pageSize: 10,
        total: 0
    },
    /** 分页布局 */
    Page_Layout: '->,total, sizes, prev, pager, next, jumper',
    /** 只有一页时隐藏分页 */
    Page_isHideOnSinglePage: false,

    /** 查询时api接口name名称 */
    ApiName: {
        query: 'query',
        add: 'add',
        edit: 'edit',
        delete: 'delete',
        deleteFlag: 'deleteFlag',
        remove: 'remove'
    },
    /** 渲染时页面节点权限参数 */
    Permission: {
        add: 'add',
        edit: 'edit',
        delete: 'delete',
        deleteFlag: 'deleteFlag',
        remove: 'remove'
    },
    /** 所拥有的权限列表 */
    Permissions: ['add', 'edit', 'delete', 'deleteFlag', 'remove']
}

/** 组件共享参数 */
export const DefCrudState: CrusStateType = {
    CompRef: {},
    /** 当前操作是新增还是编辑 */
    Mode: 'add',
    /**新增/编辑对话框可见 */
    DialogVisible: false,
    /**表格加载状态 */
    tableLoading: false,
    /**表单提交加载状态 */
    submitLoading: false,
    /** 编辑表单 页脚显示状态 */
    DialogVisibleFooterButton: true,

    /** 拆分元素 */
    ElementArrs: { filter: {}, editor: {}, column: {}, expand: {}, columns: {} },
    // TODO:表格列动态展示未启动
    /** 要展示的表格列 */
    tableColumn: [],
    /**存储原始数据 */
    originalData: [],
    /**请求的数据 */
    tableData: [],
    /**选中的数据 */
    multipleSelection: [],
    /**上传的文件暂存 */
    uploadFiles: [],

    /**初始化的值 */
    initSearchModel: {},
    initEditModel: {},

    /**路由传参的值 */
    searchFormValue: {},
    /**搜索表单数据 */
    searchModel: {},
    /** 原始编辑值 */
    editFormValue: {},
    /**编辑表单数据 */
    editModel: {}
}

/** 根组件传入的Props */
export let DefCrudProps: CrudPropsType
